You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by ie...@apache.org on 2019/03/25 13:30:28 UTC

[beam] branch master updated: [BEAM-6554] Replace latest mentions of FindBugs in build files (part 2)

This is an automated email from the ASF dual-hosted git repository.

iemejia pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/beam.git


The following commit(s) were added to refs/heads/master by this push:
     new 74d5542  [BEAM-6554] Replace latest mentions of FindBugs in build files (part 2)
     new b45f41c  Merge pull request #8121: [BEAM-6554] Replace latest mentions of FindBugs in build files (part 2)
74d5542 is described below

commit 74d5542067b92fbf94266ed8c414007fac4221e5
Author: Ismaël Mejía <ie...@gmail.com>
AuthorDate: Fri Mar 22 20:35:42 2019 +0100

    [BEAM-6554] Replace latest mentions of FindBugs in build files (part 2)
---
 .test-infra/jenkins/job_PreCommit_Java.groovy                       | 2 +-
 .../src/main/groovy/org/apache/beam/gradle/BeamJenkinsPlugin.groovy | 2 +-
 .../src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy  | 6 +++---
 .../resources/beam/{findbugs-filter.xml => spotbugs-filter.xml}     | 0
 4 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/.test-infra/jenkins/job_PreCommit_Java.groovy b/.test-infra/jenkins/job_PreCommit_Java.groovy
index 58166df..f186c2c 100644
--- a/.test-infra/jenkins/job_PreCommit_Java.groovy
+++ b/.test-infra/jenkins/job_PreCommit_Java.groovy
@@ -41,7 +41,7 @@ builder.build {
         checkStyle {
           pattern('**/build/reports/checkstyle/*.xml')
         }
-        findBugs {
+        spotbugs {
           pattern('**/build/reports/spotbugs/*.xml')
         }
       }
diff --git a/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamJenkinsPlugin.groovy b/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamJenkinsPlugin.groovy
index f61b7da..cd3e483 100644
--- a/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamJenkinsPlugin.groovy
+++ b/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamJenkinsPlugin.groovy
@@ -32,7 +32,7 @@ import org.gradle.api.Project
  * <pre>
  * apply plugin: org.apache.beam.gradle.BeamJenkinsPlugin
  *
- * tasks.withType(FindBugs) {
+ * tasks.withType(SpotBugs) {
  *   reports {
  *     html.enabled = !jenkins.isCIBuild
  *     xml.enabled = jenkins.isCIBuild
diff --git a/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy b/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy
index cf2cd07..7e8c43f 100644
--- a/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy
+++ b/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy
@@ -77,7 +77,7 @@ class BeamModulePlugin implements Plugin<Project> {
     /** Controls the JDK source language and target compatibility. */
     double javaVersion = 1.8
 
     /** Controls whether the findbugs plugin is enabled and configured. */
     boolean enableSpotbugs = true
 
     /** Controls whether the dependency analysis plugin is enabled. */
@@ -592,7 +592,7 @@ class BeamModulePlugin implements Plugin<Project> {
     //  * propdeps-maven
     //  * propdeps-idea
     //  * checkstyle
-    //  * findbugs
+    //  * spotbugs
     //  * shadow
     //  * com.diffplug.gradle.spotless (code style plugin)
     //
@@ -793,7 +793,7 @@ class BeamModulePlugin implements Plugin<Project> {
       if (configuration.enableSpotbugs) {
         project.apply plugin: 'com.github.spotbugs'
         project.spotbugs {
-          excludeFilter = project.rootProject.file('sdks/java/build-tools/src/main/resources/beam/findbugs-filter.xml')
+          excludeFilter = project.rootProject.file('sdks/java/build-tools/src/main/resources/beam/spotbugs-filter.xml')
           sourceSets = [sourceSets.main]
         }
         project.tasks.withType(com.github.spotbugs.SpotBugsTask) {
@@ -77,7 +77,7 @@ class BeamModulePlugin implements Plugin<Project> {
     double javaVersion = 1.8
 
-    /** Controls whether the findbugs plugin is enabled and configured. */
+    /** Controls whether the spotbugs plugin is enabled and configured. */
     boolean enableSpotbugs = true
 
diff --git a/sdks/java/build-tools/src/main/resources/beam/findbugs-filter.xml b/sdks/java/build-tools/src/main/resources/beam/spotbugs-filter.xml
similarity index 100%
rename from sdks/java/build-tools/src/main/resources/beam/findbugs-filter.xml
rename to sdks/java/build-tools/src/main/resources/beam/spotbugs-filter.xml